@@ -6,14 +6,14 @@
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "powerpc"
 #define HOST_VENDOR "apple"
-#define HOST_OS "macosx-10.4.5"
+#define HOST_OS "macosx-10.4.6"
 #define HOST_OS_NAME "macosx-10"
-#define HOST_OS_VERSION "10.4.5"
+#define HOST_OS_VERSION "10.4.6"
 #define HOST_ARCH "powerpc"
 #define DISTRO_NAME "none"
 #define HOST_NAME "a-osx.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Sun Apr 16 18:31:44 EDT 2006"
+#define CONFIG_DATE "Thu May 11 11:28:25 EDT 2006"
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_VERSION "6.2a2"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
@@ -34,7 +34,7 @@
 #ifdef __cplusplus
 #include <stdlib.h>
 #endif
-#define HOST_HEADER_VERSION "10.4.5"
+#define HOST_HEADER_VERSION "10.4.6"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBLDAP 1
 #define HAVE_UNISTD_H 1
@@ -188,6 +188,7 @@
 #define HAVE_UNISTD_H 1
 #define HAVE_LBER_H 1
 #define HAVE_LDAP_H 1
+#define NEW_DBM_H "ndbm.h"
 #define TIME_WITH_SYS_TIME 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_darwin.h"
 #define HAVE_STRUCT_NFS_ARGS 1
@@ -268,6 +269,8 @@
 #define HAVE_MAP_EXEC 1
 #define HAVE_LDAP_OPEN 1
 #define HAVE_MAP_LDAP 1
+#define HAVE_DBM_OPEN 1
+#define HAVE_MAP_NDBM 1
 #define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
 #define HAVE_GETPWNAM 1
